==> jc-1.4.0.tar.gz: gnu/xml/transform/XSLComparator.h <==
// class gnu.xml.transform.XSLComparator

// class file dependencies
// @dep_class 552d9fb60f855baa gnu_xml_transform_XSLComparator
// @dep_class 2a7152deee1944f1 java_lang_Object

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_gnu_xml_transform_XSLComparator_H_
#define _JC_gnu_xml_transform_XSLComparator_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Object$object;
struct _jc_java_util_List$object;

// Typedefs
typedef struct _jc_gnu_xml_transform_XSLComparator$sub_refs	_jc_gnu_xml_transform_XSLComparator$sub_refs;
typedef struct _jc_gnu_xml_transform_XSLComparator$sub_nonrefs	_jc_gnu_xml_transform_XSLComparator$sub_nonrefs;
typedef struct _jc_gnu_xml_transform_XSLComparator$refs	_jc_gnu_xml_transform_XSLComparator$refs;
typedef struct _jc_gnu_xml_transform_XSLComparator$nonrefs	_jc_gnu_xml_transform_XSLComparator$nonrefs;
typedef struct _jc_gnu_xml_transform_XSLComparator$object	_jc_gnu_xml_transform_XSLComparator$object;

typedef const struct _jc_gnu_xml_transform_XSLComparator$vmethods	_jc_gnu_xml_transform_XSLComparator$vmethods;
typedef const struct _jc_gnu_xml_transform_XSLComparator$vtable	_jc_gnu_xml_transform_XSLComparator$vtable;
typedef const struct _jc_gnu_xml_transform_XSLComparator$vtype	_jc_gnu_xml_transform_XSLComparator$vtype;

// Constructors
extern void _jc_gnu_xml_transform_XSLComparator$method$_init$dd8ff073a2c7f994(_jc_env *, struct _jc_gnu_xml_transform_XSLComparator$object *, struct _jc_object *);

// Virtual methods
extern jint _jc_gnu_xml_transform_XSLComparator$method$compare$ef65339aa5f9531b(_jc_env *, struct _jc_gnu_xml_transform_XSLComparator$object *, struct _jc_java_lang_Object$object *, struct _jc_java_lang_Object$object *);

// Virtual method descriptors
extern _jc_method _jc_gnu_xml_transform_XSLComparator$method_info$compare$ef65339aa5f9531b;

// Virtual methods structure
struct _jc_gnu_xml_transform_XSLComparator$vmethods {
	jint	(*compare$ef65339aa5f9531b)(_jc_env *, struct _jc_gnu_xml_transform_XSLComparator$object *, struct _jc_java_lang_Object$object *, struct _jc_java_lang_Object$object *);
};

// Vtable
struct _jc_gnu_xml_transform_XSLComparator$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_gnu_xml_transform_XSLComparator$vmethods	gnu_xml_transform_XSLComparator;
};

// Vtype
struct _jc_gnu_xml_transform_XSLComparator$vtype {
	_jc_type			type;
	_jc_gnu_xml_transform_XSLComparator$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_gnu_xml_transform_XSLComparator$sub_refs {
	struct _jc_object	*sortKeys;
};

// Reference instance fields (object)
struct _jc_gnu_xml_transform_XSLComparator$refs {
    _jc_gnu_xml_transform_XSLComparator$sub_refs	gnu_xml_transform_XSLComparator;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_gnu_xml_transform_XSLComparator$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_gnu_xml_transform_XSLComparator$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_gnu_xml_transform_XSLComparator$sub_nonrefs	gnu_xml_transform_XSLComparator;
};

// Object instance structure
struct _jc_gnu_xml_transform_XSLComparator$object {
	_jc_gnu_xml_transform_XSLComparator$refs	refs[0];
	_jc_word		lockword;
	_jc_gnu_xml_transform_XSLComparator$vtype	*vtype;
	_jc_gnu_xml_transform_XSLComparator$nonrefs	nonrefs;
};

// Type structure
extern _jc_gnu_xml_transform_XSLComparator$vtype _jc_gnu_xml_transform_XSLComparator$type;

// Array types class info structures
_JC_DECL_ARRAYS(gnu_xml_transform_XSLComparator, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_gnu_xml_transform_XSLComparator$class_object;

#endif	/* _JC_gnu_xml_transform_XSLComparator_H_ */

==> jc-1.4.6.tar.gz: gnu/xml/transform/XSLComparator.h <==
// class gnu.xml.transform.XSLComparator

// class file dependencies
// @dep_class 552d9fb60f855baa gnu_xml_transform_XSLComparator
// @dep_class 1c4f1fc002fc96e5 java_lang_Object

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_gnu_xml_transform_XSLComparator_H_
#define _JC_gnu_xml_transform_XSLComparator_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Object$object;
struct _jc_java_util_List$object;

// Typedefs
typedef struct _jc_gnu_xml_transform_XSLComparator$sub_refs	_jc_gnu_xml_transform_XSLComparator$sub_refs;
typedef struct _jc_gnu_xml_transform_XSLComparator$sub_nonrefs	_jc_gnu_xml_transform_XSLComparator$sub_nonrefs;
typedef struct _jc_gnu_xml_transform_XSLComparator$refs	_jc_gnu_xml_transform_XSLComparator$refs;
typedef struct _jc_gnu_xml_transform_XSLComparator$nonrefs	_jc_gnu_xml_transform_XSLComparator$nonrefs;
typedef struct _jc_gnu_xml_transform_XSLComparator$object	_jc_gnu_xml_transform_XSLComparator$object;

typedef const struct _jc_gnu_xml_transform_XSLComparator$vmethods	_jc_gnu_xml_transform_XSLComparator$vmethods;
typedef const struct _jc_gnu_xml_transform_XSLComparator$vtable	_jc_gnu_xml_transform_XSLComparator$vtable;
typedef const struct _jc_gnu_xml_transform_XSLComparator$vtype	_jc_gnu_xml_transform_XSLComparator$vtype;

// Constructors
extern void _jc_gnu_xml_transform_XSLComparator$method$_init$dd8ff073a2c7f994(_jc_env *, struct _jc_gnu_xml_transform_XSLComparator$object *, struct _jc_object *) _JC_JCNI_ATTR;

// Virtual methods
extern jint _jc_gnu_xml_transform_XSLComparator$method$compare$ef65339aa5f9531b(_jc_env *, struct _jc_gnu_xml_transform_XSLComparator$object *, struct _jc_java_lang_Object$object *, struct _jc_java_lang_Object$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_gnu_xml_transform_XSLComparator$method_info$compare$ef65339aa5f9531b;

// Virtual methods structure
struct _jc_gnu_xml_transform_XSLComparator$vmethods {
	jint	(*compare$ef65339aa5f9531b)(_jc_env *, struct _jc_gnu_xml_transform_XSLComparator$object *, struct _jc_java_lang_Object$object *, struct _jc_java_lang_Object$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_gnu_xml_transform_XSLComparator$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_gnu_xml_transform_XSLComparator$vmethods	gnu_xml_transform_XSLComparator;
};

// Vtype
struct _jc_gnu_xml_transform_XSLComparator$vtype {
	_jc_type			type;
	_jc_gnu_xml_transform_XSLComparator$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_gnu_xml_transform_XSLComparator$sub_refs {
	struct _jc_object	*sortKeys;
};

// Reference instance fields (object)
struct _jc_gnu_xml_transform_XSLComparator$refs {
    _jc_gnu_xml_transform_XSLComparator$sub_refs	gnu_xml_transform_XSLComparator;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_gnu_xml_transform_XSLComparator$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_gnu_xml_transform_XSLComparator$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_gnu_xml_transform_XSLComparator$sub_nonrefs	gnu_xml_transform_XSLComparator;
};

// Object instance structure
struct _jc_gnu_xml_transform_XSLComparator$object {
	_jc_gnu_xml_transform_XSLComparator$refs	refs[0];
	_jc_word		lockword;
	_jc_gnu_xml_transform_XSLComparator$vtype	*vtype;
	_jc_gnu_xml_transform_XSLComparator$nonrefs	nonrefs;
};

// Type structure
extern _jc_gnu_xml_transform_XSLComparator$vtype _jc_gnu_xml_transform_XSLComparator$type;

// Array types class info structures
_JC_DECL_ARRAYS(gnu_xml_transform_XSLComparator, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_gnu_xml_transform_XSLComparator$class_object;

#endif	/* _JC_gnu_xml_transform_XSLComparator_H_ */
